diff mbox series

[04/11] reboot: rename now misleading hw_protection symbols

Message ID 20241219-hw_protection-reboot-v1-4-263a0c1df802@pengutronix.de
State New
Headers show
Series reboot: support runtime configuration of emergency hw_protection action | expand

Commit Message

Ahmad Fatoum Dec. 19, 2024, 7:31 a.m. UTC
The __hw_protection_shutdown, hw_failure_emergency_poweroff_work and
hw_failure_emergency_poweroff_func symbol names have become misleading,
because they can either cause a shutdown (poweroff) or a reboot
depending on an argument or a global variable.

To avoid further confusion, let's rename them, so they don't suggest
that a poweroff is all they can do.

Signed-off-by: Ahmad Fatoum <a.fatoum@pengutronix.de>
---
 include/linux/reboot.h |  8 ++++----
 kernel/reboot.c        | 22 +++++++++++-----------
 2 files changed, 15 insertions(+), 15 deletions(-)
diff mbox series

Patch

diff --git a/include/linux/reboot.h b/include/linux/reboot.h
index d6780fbf51535e1f98b576da0a06701402dfd447..b1e2c86d29a281abbcfe69bc00321df185c32c91 100644
--- a/include/linux/reboot.h
+++ b/include/linux/reboot.h
@@ -180,17 +180,17 @@  extern void orderly_reboot(void);
 
 enum hw_protection_action { HWPROT_ACT_SHUTDOWN, HWPROT_ACT_REBOOT };
 
-void __hw_protection_shutdown(const char *reason, int ms_until_forced,
-			      enum hw_protection_action action);
+void __hw_protection_trigger(const char *reason, int ms_until_forced,
+			     enum hw_protection_action action);
 
 static inline void hw_protection_reboot(const char *reason, int ms_until_forced)
 {
-	__hw_protection_shutdown(reason, ms_until_forced, HWPROT_ACT_REBOOT);
+	__hw_protection_trigger(reason, ms_until_forced, HWPROT_ACT_REBOOT);
 }
 
 static inline void hw_protection_shutdown(const char *reason, int ms_until_forced)
 {
-	__hw_protection_shutdown(reason, ms_until_forced, HWPROT_ACT_SHUTDOWN);
+	__hw_protection_trigger(reason, ms_until_forced, HWPROT_ACT_SHUTDOWN);
 }
 
 /*
diff --git a/kernel/reboot.c b/kernel/reboot.c
index 8e3680d36654587b57db44806a3d7b0228b10f67..da6c8bdeeefe627a76c7ec6e8926138ebbe3ae4e 100644
--- a/kernel/reboot.c
+++ b/kernel/reboot.c
@@ -947,13 +947,13 @@  static const char *hw_protection_action_str(enum hw_protection_action action)
 static enum hw_protection_action hw_failure_emergency_action;
 
 /**
  * hw_failure_emergency_poweroff_func - emergency poweroff work after a known delay
  * @work: work_struct associated with the emergency poweroff function
  *
  * This function is called in very critical situations to force
- * a kernel poweroff after a configurable timeout value.
+ * a kernel poweroff or reboot after a configurable timeout value.
  */
-static void hw_failure_emergency_poweroff_func(struct work_struct *work)
+static void hw_failure_emergency_action_func(struct work_struct *work)
 {
 	const char *action_str = hw_protection_action_str(hw_failure_emergency_action);
 
@@ -981,8 +981,8 @@  static void hw_failure_emergency_poweroff_func(struct work_struct *work)
 	emergency_restart();
 }
 
-static DECLARE_DELAYED_WORK(hw_failure_emergency_poweroff_work,
-			    hw_failure_emergency_poweroff_func);
+static DECLARE_DELAYED_WORK(hw_failure_emergency_action_work,
+			    hw_failure_emergency_action_func);
 
 /**
  * hw_failure_emergency_schedule - Schedule an emergency system shutdown or reboot
@@ -996,12 +996,12 @@  static void hw_failure_emergency_schedule(enum hw_protection_action action,
 	if (poweroff_delay_ms <= 0)
 		return;
 	hw_failure_emergency_action = action;
-	schedule_delayed_work(&hw_failure_emergency_poweroff_work,
+	schedule_delayed_work(&hw_failure_emergency_action_work,
 			      msecs_to_jiffies(poweroff_delay_ms));
 }
 
 /**
  * __hw_protection_shutdown - Trigger an emergency system shutdown or reboot
  *
  * @reason:		Reason of emergency shutdown or reboot to be printed.
  * @ms_until_forced:	Time to wait for orderly shutdown or reboot before
@@ -1018,8 +1018,8 @@  static void hw_failure_emergency_schedule(enum hw_protection_action action,
  * pending even if the previous request has given a large timeout for forced
  * shutdown/reboot.
  */
-void __hw_protection_shutdown(const char *reason, int ms_until_forced,
-			      enum hw_protection_action action)
+void __hw_protection_trigger(const char *reason, int ms_until_forced,
+			     enum hw_protection_action action)
 {
 	static atomic_t allow_proceed = ATOMIC_INIT(1);
 
@@ -1039,7 +1039,7 @@  void __hw_protection_shutdown(const char *reason, int ms_until_forced,
 	else
 		orderly_poweroff(true);
 }
-EXPORT_SYMBOL_GPL(__hw_protection_shutdown);
+EXPORT_SYMBOL_GPL(__hw_protection_trigger);
 
 static int __init reboot_setup(char *str)
 {
@@ -947,13 +947,13 @@  static const char *hw_protection_action_str(enum hw_protection_action action)
 
 /**
- * hw_failure_emergency_poweroff_func - emergency poweroff work after a known delay
- * @work: work_struct associated with the emergency poweroff function
+ * hw_failure_emergency_action_func - emergency action after a known delay
+ * @work: work_struct associated with the emergency action function
  *
  * This function is called in very critical situations to force
@@ -996,12 +996,12 @@  static void hw_failure_emergency_schedule(enum hw_protection_action action,
 
 /**
- * __hw_protection_shutdown - Trigger an emergency system shutdown or reboot
+ * __hw_protection_trigger - Trigger an emergency system shutdown or reboot
  *
  * @reason:		Reason of emergency shutdown or reboot to be printed.